@@ -146,10 +146,10 @@ MetaData: TypeAlias = Optional[Hashable]
 
 
 @runtime_checkable
-class CustomTreeNode(Protocol[T]):
+class CustomTreeNode(Protocol[T]):  # pylint: disable=too-few-public-methods
     """The abstract base class for custom pytree nodes."""
 
-    def tree_flatten(
+    def __tree_flatten__(
         self,
         /,
     ) -> (
@@ -162,7 +162,7 @@ class CustomTreeNode(Protocol[T]):
         """Flatten the custom pytree node into children and metadata."""
 
     @classmethod
-    def tree_unflatten(cls, metadata: MetaData, children: Children[T], /) -> Self:
+    def __tree_unflatten__(cls, metadata: MetaData, children: Children[T], /) -> Self:
         """Unflatten the children and metadata into the custom pytree node."""
 
 
@@ -290,7 +290,7 @@ class PyTree(Generic[T]):  # pragma: no cover
         """Emulate dataclass-like behavior."""
         raise NotImplementedError
 
-    def __contains__(self, key: Any | T, /) -> bool:
+    def __contains__(self, key: Any, /) -> bool:
         """Emulate collection-like behavior."""
         raise NotImplementedError
 
@@ -302,15 +302,15 @@ class PyTree(Generic[T]):  # pragma: no cover
         """Emulate collection-like behavior."""
         raise NotImplementedError
 
-    def index(self, key: Any | T, /) -> int:
+    def index(self, key: Any, /) -> int:
         """Emulate sequence-like behavior."""
         raise NotImplementedError
 
-    def count(self, key: Any | T, /) -> int:
+    def count(self, key: Any, /) -> int:
         """Emulate sequence-like behavior."""
         raise NotImplementedError
 
-    def get(self, key: Any, /, default: T | None = None) -> T | None:
+    def get(self, key: Any, /, default: S | None = None) -> PyTree[T] | T | S | None:
         """Emulate mapping-like behavior."""
         raise NotImplementedError
 
@@ -483,7 +483,7 @@ class StructSequenceMeta(type):
 # `StructSequence` classes are unsubclassable, so are all decorated with `@final`.
 # pylint: disable-next=invalid-name,missing-class-docstring
 @final
-class StructSequence(tuple[_T_co, ...], metaclass=StructSequenceMeta):  # type: ignore[misc]
+class StructSequence(tuple[_T_co, ...], metaclass=StructSequenceMeta):
     """A generic type stub for CPython's ``PyStructSequence`` type."""
 
     __slots__: ClassVar[tuple[()]] = ()
@@ -502,7 +502,7 @@ class StructSequence(tuple[_T_co, ...], metaclass=StructSequenceMeta):  # type:
         raise NotImplementedError
 
 
-structseq: TypeAlias = StructSequence  # noqa: PYI042
+structseq: TypeAlias = StructSequence  # noqa: PYI042 # pylint: disable=invalid-name
 
 del StructSequenceMeta
 
@@ -521,7 +521,7 @@ def is_structseq_instance(obj: object, /) -> bool:
 
 
 # Set if the type allows subclassing (see CPython's Include/object.h)
-Py_TPFLAGS_BASETYPE: int = _C.Py_TPFLAGS_BASETYPE  # (1UL << 10)
+Py_TPFLAGS_BASETYPE: int = _C.Py_TPFLAGS_BASETYPE  # (1UL << 10)  # pylint: disable=invalid-name
 
 
 @_override_with_(_C.is_structseq_class)
